@@ -107,11 +107,21 @@ sub formbuilder_setup (@) {
 	my $cgi=$params{cgi};
 
 	if ($form->title eq "preferences" &&
-	    is_admin_or_owner($params{session}) &&
-	    $config{controlsitecgiurl}) {
-		push @{$params{buttons}}, "Control Panel";
-		if ($form->submitted && $form->submitted eq "Control Panel") {
-			controlpanelredir($cgi);
+	    is_admin_or_owner($params{session})) {
+		if ($config{controlsitecgiurl}) {
+			push @{$params{buttons}}, "Control Panel";
+			if ($form->submitted && $form->submitted eq "Control Panel") {
+				controlpanelredir($cgi);
+			}
+		}
+		eval q{use IkiWiki::Hosting};
+		error $@ if $@;
+		IkiWiki::Hosting::readconfig();
+		if ($config{allow_analog_reports}) {
+			push @{$params{buttons}}, "Statistics";
+			if ($form->submitted && $form->submitted eq "Statistics") {
+				analog_report($cgi, $params{session});
+			}
 		}
 	}
 	if ($form->title eq "setup" &&
@@ -285,7 +295,7 @@ sub setupdns ($$){
 	exit 0;
 }
 
-sub setupsshkeys ($$){
+sub setupsshkeys ($$) {
 	my $cgi=shift;
 	my $session=shift;
 
@@ -340,6 +350,13 @@ sub setupsshkeys ($$){
 		key_urlencoded => uri_escape($_),
 	}, grep defined, @keys]);
 
+	# Ikiwiki will be running as the site's username, 
+	my $username=(getpwuid($<))[0]; 
+	if (defined $username && length $username && 
+	    defined $config{hostname} && length $config{hostname}) { 
+		$template->param(sshaddress => "$username\@$config{hostname}");
+	} 
+
 	IkiWiki::printheader($session);
 	print IkiWiki::cgitemplate($cgi, "SSH keys", $template->output);
 
@@ -453,4 +470,21 @@ sub get_ssh_public_key {
 	return shift(@keys);
 }
 
+sub analog_report ($$) {
+	my $cgi=shift;
+	my $session=shift;
+
+	IkiWiki::needsignin($cgi, $session);
+	if (! is_admin_or_owner($session)) {
+		error "You are not logged in as an admin or site owner.";
+	}
+	
+	print "Content-type: text/html\n\n";
+	system("ikisite", $config{hostname}, "analog", "--"
+		, "-a" # html output
+		, "+CHOSTNAME 'this site'"
+	);
+	exit 0;
+}
+
 1
